Exception: Inquirex::Errors::RequiredStepError

Inherits:
EngineError show all
Defined in:
lib/inquirex/errors.rb

Overview

Raised when Engine#skip is called on a step that is required (the default). Only steps declared with required false may be skipped by the user.